.. omnivore documentation master file, created by sphinx-quickstart on Thu May  8 10:52:56 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

User Manual
===========

Contents:

.. toctree::
   :maxdepth: 3

   intro

Development Notes:

.. toctree::
   :maxdepth: 3

   tasks_and_applications
   plugins
   preferences
   mime_types.rst
   editor_area
   menus_and_actions

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

